@@ -816,10 +816,12 @@ def kinematic_scattering(tags, verbose=False):
     rotation_matrix = get_rotation_matrix(tags)
 
     if verbose:
+
         print(f"Rotation alpha {np.rad2deg(tags['y-axis rotation alpha']):.1f} degree, "
               f" beta {np.rad2deg(tags['x-axis rotation beta']):.1f} degree")
-        print(f"Tilting {1} by {np.rad2deg(tags['mistilt alpha']),:.2f} " 
-              f"in alpha and {np.rad2deg(tags['mistilt beta']):.2f} in beta direction results in :")
+        print(f"from zone axis {tags['zone_hkl']}")
+        print(f"Tilting {1} by {np.rad2deg(tags['mistilt alpha']):.2f} " 
+              f" in alpha and {np.rad2deg(tags['mistilt beta']):.2f} in beta direction results in :")
         # list(tags['zone_hkl'])
         #
         # print(f"zone axis {list(tags['nearest_zone_axis'])} with a mistilt of "
